@@ -29,9 +29,16 @@ rest_build_location_elements <- function(request, values, build_get_query) {
 
     location <- tag_get(field, "location")
     if (location == "headers") {
-      request$http_request$header <- rest_build_header_map(request$http_request$header, field)
+      request$http_request$header <- rest_build_header_map(
+        request$http_request$header,
+        field
+      )
     } else if (location == "header") {
-      request$http_request$header <- rest_build_header(request$http_request$header, field, name)
+      request$http_request$header <- rest_build_header(
+        request$http_request$header,
+        field,
+        name
+      )
     } else if (location == "uri") {
       request$http_request$url <- rest_build_uri(request$http_request$url, field, name)
     } else if (location == "querystring") {
@@ -67,8 +74,18 @@ rest_build_uri <- function(uri, value, name) {
   str <- convert_type(value, timestamp_format = "unix")
   uri$path <- sub(sprintf("{%s}", name), str, uri$path, fixed = TRUE)
   uri$path <- sub(sprintf("{%s+}", name), str, uri$path, fixed = TRUE)
-  uri$raw_path <- sub(sprintf("{%s}", name), escape_path(str, TRUE), uri$raw_path, fixed = TRUE)
-  uri$raw_path <- sub(sprintf("{%s+}", name), escape_path(str, FALSE), uri$raw_path, fixed = TRUE)
+  uri$raw_path <- sub(
+    sprintf("{%s}", name),
+    escape_path(str, TRUE),
+    uri$raw_path,
+    fixed = TRUE
+  )
+  uri$raw_path <- sub(
+    sprintf("{%s+}", name),
+    escape_path(str, FALSE),
+    uri$raw_path,
+    fixed = TRUE
+  )
   return(uri)
 }
 
@@ -174,7 +191,8 @@ rest_unmarshal_status_code <- function(status_code) {
 
 # Unmarshal a header.
 rest_unmarshal_header <- function(value, type) {
-  convert <- switch(type,
+  convert <- switch(
+    type,
     blob = base64_to_raw,
     boolean = as.logical,
     double = as.numeric,
@@ -193,9 +211,11 @@ rest_unmarshal_header <- function(value, type) {
 # Unmarshal a collection of header values that share a common prefix.
 rest_unmarshal_header_map <- function(values, prefix, type) {
   value_names <- names(values)
-  value_names <- value_names[
-    grepl(sprintf("^%s", prefix), value_names, ignore.case = TRUE)
-  ]
+  value_names <- value_names[grepl(
+    sprintf("^%s", prefix),
+    value_names,
+    ignore.case = TRUE
+  )]
   result <- lapply(value_names, function(name) {
     rest_unmarshal_header(values[[name]], type)
   })
