@@ -81,7 +81,8 @@ xml_build <- function(params) {
 
   t <- type(params)
 
-  build_fn <- switch(t,
+  build_fn <- switch(
+    t,
     structure = xml_build_structure,
     list = xml_build_list,
     xml_build_scalar
@@ -155,7 +156,8 @@ xml_build_scalar <- function(params) {
     return(NULL)
   }
   t <- tag_get(params, "type")
-  convert <- switch(t,
+  convert <- switch(
+    t,
     blob = raw_to_base64,
     boolean = convert_boolean,
     double = as.numeric,
@@ -254,13 +256,12 @@ xml_parse <- function(data, interface, data_nms, flattened = NULL) {
       # Check if element exists in response
       found <- (key == data_nms)
     }
-    result[[i]] <- (
-      if (any(found)) {
-        xml_elts <- data[found]
-        parse_xml_elt(xml_elts, interface_i, tags_i, flattened)
-      } else {
-        default_parse_xml(interface_i, tags_i)
-      })
+    result[[i]] <- (if (any(found)) {
+      xml_elts <- data[found]
+      parse_xml_elt(xml_elts, interface_i, tags_i, flattened)
+    } else {
+      default_parse_xml(interface_i, tags_i)
+    })
   }
   names(result) <- nms
   return(result)
@@ -270,7 +271,8 @@ parse_xml_elt <- function(xml_elts, interface_i, tags_i, flattened = NULL) {
   tag_type <- tags_i[["type"]]
   flattened <- flattened %||% tags_i[["flattened"]]
   t <- type(interface_i)
-  parse_fn <- switch(t,
+  parse_fn <- switch(
+    t,
     structure = xml_parse_structure,
     map = xml_parse_map,
     list = xml_parse_list,
@@ -282,7 +284,13 @@ parse_xml_elt <- function(xml_elts, interface_i, tags_i, flattened = NULL) {
   return(result)
 }
 
-xml_parse_structure <- function(xml_elts, interface_i, tags_i, tag_type = NULL, flattened = NULL) {
+xml_parse_structure <- function(
+  xml_elts,
+  interface_i,
+  tags_i,
+  tag_type = NULL,
+  flattened = NULL
+) {
   xml_elt <- xml2::xml_contents(xml_elts)
   result <- xml_parse(xml_elt, interface_i, xml2::xml_name(xml_elt), flattened)
 
@@ -296,7 +304,13 @@ xml_parse_structure <- function(xml_elts, interface_i, tags_i, tag_type = NULL,
   return(result)
 }
 
-xml_parse_map <- function(xml_elts, interface_i, tags_i, tag_type = NULL, flattened = NULL) {
+xml_parse_map <- function(
+  xml_elts,
+  interface_i,
+  tags_i,
+  tag_type = NULL,
+  flattened = NULL
+) {
   if (length(xml_elts) == 0) {
     return(list())
   }
@@ -308,14 +322,22 @@ xml_parse_map <- function(xml_elts, interface_i, tags_i, tag_type = NULL, flatte
   if (isTRUE(flattened)) {
     for (i in seq_along(xml_elts)) {
       result[[i]] <- xml_parse_map_entry(
-        xml_elts[[i]], interface_i, key_name, value_name, flattened
+        xml_elts[[i]],
+        interface_i,
+        key_name,
+        value_name,
+        flattened
       )
     }
   } else {
     contents <- xml2::xml_contents(xml_elts)
     for (i in seq_along(contents)) {
       result[[i]] <- xml_parse_map_entry(
-        contents[[i]], interface_i, key_name, value_name, flattened
+        contents[[i]],
+        interface_i,
+        key_name,
+        value_name,
+        flattened
       )
     }
   }
@@ -323,7 +345,13 @@ xml_parse_map <- function(xml_elts, interface_i, tags_i, tag_type = NULL, flatte
   return(result)
 }
 
-xml_parse_map_entry <- function(xml_elts_i, interface_i, key_name, value_name, flattened) {
+xml_parse_map_entry <- function(
+  xml_elts_i,
+  interface_i,
+  key_name,
+  value_name,
+  flattened
+) {
   contents <- xml2::xml_contents(xml_elts_i)
   contents_nms <- xml2::xml_name(contents)
 
@@ -338,7 +366,13 @@ xml_parse_map_entry <- function(xml_elts_i, interface_i, key_name, value_name, f
   return(result)
 }
 
-xml_parse_list <- function(xml_elts, interface_i, tags_i, tag_type = NULL, flattened = NULL) {
+xml_parse_list <- function(
+  xml_elts,
+  interface_i,
+  tags_i,
+  tag_type = NULL,
+  flattened = NULL
+) {
   contents <- xml2::xml_contents(xml_elts)
   xml_nms <- xml2::xml_name(contents)
   nms <- names(interface_i[[1]])
@@ -364,10 +398,17 @@ xml_parse_list <- function(xml_elts, interface_i, tags_i, tag_type = NULL, flatt
   return(result)
 }
 
-xml_parse_scalar <- function(xml_elts, interface_i, tags_i, tag_type = NULL, flattened = NULL) {
+xml_parse_scalar <- function(
+  xml_elts,
+  interface_i,
+  tags_i,
+  tag_type = NULL,
+  flattened = NULL
+) {
   results <- xml2::xml_text(xml_elts)
 
-  convert <- switch(tag_type,
+  convert <- switch(
+    tag_type,
     blob = base64_to_raw,
     boolean = as.logical,
     double = as.numeric,
@@ -389,7 +430,8 @@ default_parse_xml <- function(interface_i, tags_i) {
   tag_type <- tags_i[["type"]]
 
   t <- type(interface_i)
-  parse_fn <- switch(t,
+  parse_fn <- switch(
+    t,
     structure = default_parse_structure,
     map = default_parse_map,
     list = default_parse_list,
@@ -449,7 +491,8 @@ xml_scalar_default <- function(interface, default) {
 }
 
 default_parse_scalar <- function(interface_i, tag_type = NULL) {
-  result <- switch(tag_type,
+  result <- switch(
+    tag_type,
     integer = xml_scalar_default(interface_i, numeric()),
     double = xml_scalar_default(interface_i, numeric()),
     long = xml_scalar_default(interface_i, numeric()),
@@ -463,12 +506,24 @@ default_parse_scalar <- function(interface_i, tag_type = NULL) {
 
 transpose <- function(x) {
   lens <- lengths(x)
+  max_len <- max(lens)
   if (any(found <- lens == 0)) {
-    x[found] <- list(rep(list(), length.out = max(lens)))
+    x[found] <- list(rep(list(), length.out = max_len))
+  }
+
+  # add buffer to non list that don't match
+  found <- lens > 1 & lens < max_len & !vapply(x, is.list, FUN.VALUE = FALSE)
+  if (any(found)) {
+    buffer <- rep(NA, max_len)
+    x[found] <- lapply(x[found], pad_vector, buffer = buffer, max_len = max_len)
   }
   .mapply(list, x, NULL)
 }
 
+pad_vector <- function(x, buffer, max_len) {
+  return(c(x, buffer)[seq_len(max_len)])
+}
+
 ############## stream ##############
 xml_stream <- function(bytes, interface) {
   payload <- xml2::read_xml(bytes)
