@@ -4,26 +4,19 @@
 
 op <- Operation(name = "OperationName")
 svc <- Client(
-  client_info = ClientInfo(
-    json_version = "1.1",
-    target_prefix = "com.amazonaws.foo"
-  )
+  client_info = ClientInfo(json_version = "1.1", target_prefix = "com.amazonaws.foo")
 )
 svc$handlers$build <- HandlerList(jsonrpc_build)
 UUID_V4_PATTERN <- "[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}"
 
 op_input1 <- function(Name) {
   args <- list(Name = Name)
-  interface <- Structure(
-    Name = Scalar()
-  )
+  interface <- Structure(Name = Scalar())
   return(populate(args, interface))
 }
 
 test_that("build scalar members", {
-  input <- op_input1(
-    Name = "myname"
-  )
+  input <- op_input1(Name = "myname")
   req <- new_request(svc, op, input, NULL)
   req <- build(req)
   r <- req$http_request
@@ -34,16 +27,12 @@ test_that("build scalar members", {
 
 op_input2 <- function(TimeArg) {
   args <- list(TimeArg = TimeArg)
-  interface <- Structure(
-    TimeArg = Scalar(type = "timestamp")
-  )
+  interface <- Structure(TimeArg = Scalar(type = "timestamp"))
   return(populate(args, interface))
 }
 
 test_that("build timestamp value", {
-  input <- op_input2(
-    TimeArg = unix_time(1422172800)
-  )
+  input <- op_input2(TimeArg = unix_time(1422172800))
   req <- new_request(svc, op, input, NULL)
   req <- build(req)
   expect_equal(req$body, '{"TimeArg":1422172800}')
@@ -59,21 +48,14 @@ op_input3 <- function(BlobArg = NULL, BlobMap = NULL) {
 }
 
 test_that("build blob value", {
-  input <- op_input3(
-    BlobArg = charToRaw("foo")
-  )
+  input <- op_input3(BlobArg = charToRaw("foo"))
   req <- new_request(svc, op, input, NULL)
   req <- build(req)
   expect_equal(req$body, '{"BlobArg":"Zm9v"}')
 })
 
 test_that("build blob map", {
-  input <- op_input3(
-    BlobMap = list(
-      key1 = charToRaw("foo"),
-      key2 = charToRaw("bar")
-    )
-  )
+  input <- op_input3(BlobMap = list(key1 = charToRaw("foo"), key2 = charToRaw("bar")))
   req <- new_request(svc, op, input, NULL)
   req <- build(req)
   expect_equal(req$body, '{"BlobMap":{"key1":"Zm9v","key2":"YmFy"}}')
@@ -81,19 +63,12 @@ test_that("build blob map", {
 
 op_input4 <- function(ListParam) {
   args <- list(ListParam = ListParam)
-  interface <- Structure(
-    ListParam = List(Scalar(type = "blob"))
-  )
+  interface <- Structure(ListParam = List(Scalar(type = "blob")))
   return(populate(args, interface))
 }
 
 test_that("build blob list", {
-  input <- op_input4(
-    ListParam = list(
-      charToRaw("foo"),
-      charToRaw("bar")
-    )
-  )
+  input <- op_input4(ListParam = list(charToRaw("foo"), charToRaw("bar")))
   req <- new_request(svc, op, input, NULL)
   req <- build(req)
   expect_equal(req$body, '{"ListParam":["Zm9v","YmFy"]}')
@@ -101,20 +76,12 @@ test_that("build blob list", {
 
 op_input5 <- function(RecursiveStruct) {
   args <- list(RecursiveStruct = RecursiveStruct)
-  interface <- Structure(
-    RecursiveStruct = Structure(
-      NoRecurse = Scalar(type = "string")
-    )
-  )
+  interface <- Structure(RecursiveStruct = Structure(NoRecurse = Scalar(type = "string")))
   return(populate(args, interface))
 }
 
 test_that("build nested structure", {
-  input <- op_input5(
-    RecursiveStruct = list(
-      NoRecurse = "foo"
-    )
-  )
+  input <- op_input5(RecursiveStruct = list(NoRecurse = "foo"))
   req <- new_request(svc, op, input, NULL)
   req <- build(req)
   expect_equal(req$body, '{"RecursiveStruct":{"NoRecurse":"foo"}}')
@@ -124,22 +91,14 @@ op_input6 <- function(RecursiveStruct) {
   args <- list(RecursiveStruct = RecursiveStruct)
   interface <- Structure(
     RecursiveStruct = Structure(
-      RecursiveStruct = Structure(
-        NoRecurse = Scalar(type = "string")
-      )
+      RecursiveStruct = Structure(NoRecurse = Scalar(type = "string"))
     )
   )
   return(populate(args, interface))
 }
 
 test_that("build nested structure", {
-  input <- op_input6(
-    RecursiveStruct = list(
-      RecursiveStruct = list(
-        NoRecurse = "foo"
-      )
-    )
-  )
+  input <- op_input6(RecursiveStruct = list(RecursiveStruct = list(NoRecurse = "foo")))
   req <- new_request(svc, op, input, NULL)
   req <- build(req)
   expect_equal(req$body, '{"RecursiveStruct":{"RecursiveStruct":{"NoRecurse":"foo"}}}')
@@ -151,9 +110,7 @@ op_input7 <- function(RecursiveStruct) {
     RecursiveStruct = Structure(
       RecursiveStruct = Structure(
         RecursiveStruct = Structure(
-          RecursiveStruct = Structure(
-            NoRecurse = Scalar(type = "string")
-          )
+          RecursiveStruct = Structure(NoRecurse = Scalar(type = "string"))
         )
       )
     )
@@ -165,28 +122,23 @@ test_that("build nested structure", {
   input <- op_input7(
     RecursiveStruct = list(
       RecursiveStruct = list(
-        RecursiveStruct = list(
-          RecursiveStruct = list(
-            NoRecurse = "foo"
-          )
-        )
+        RecursiveStruct = list(RecursiveStruct = list(NoRecurse = "foo"))
       )
     )
   )
   req <- new_request(svc, op, input, NULL)
   req <- build(req)
-  expect_equal(req$body, '{"RecursiveStruct":{"RecursiveStruct":{"RecursiveStruct":{"RecursiveStruct":{"NoRecurse":"foo"}}}}}')
+  expect_equal(
+    req$body,
+    '{"RecursiveStruct":{"RecursiveStruct":{"RecursiveStruct":{"RecursiveStruct":{"NoRecurse":"foo"}}}}}'
+  )
 })
 
 op_input8 <- function(RecursiveStruct) {
   args <- list(RecursiveStruct = RecursiveStruct)
   interface <- Structure(
     RecursiveStruct = Structure(
-      RecursiveList = List(
-        Structure(
-          NoRecurse = Scalar(type = "string")
-        )
-      )
+      RecursiveList = List(Structure(NoRecurse = Scalar(type = "string")))
     )
   )
   return(populate(args, interface))
@@ -195,29 +147,25 @@ op_input8 <- function(RecursiveStruct) {
 test_that("build nested structure", {
   input <- op_input8(
     RecursiveStruct = list(
-      RecursiveList = list(
-        list(NoRecurse = "foo"),
-        list(NoRecurse = "bar")
-      )
+      RecursiveList = list(list(NoRecurse = "foo"), list(NoRecurse = "bar"))
     )
   )
   req <- new_request(svc, op, input, NULL)
   req <- build(req)
-  expect_equal(req$body, '{"RecursiveStruct":{"RecursiveList":[{"NoRecurse":"foo"},{"NoRecurse":"bar"}]}}')
+  expect_equal(
+    req$body,
+    '{"RecursiveStruct":{"RecursiveList":[{"NoRecurse":"foo"},{"NoRecurse":"bar"}]}}'
+  )
 })
 
 op_input9 <- function(RecursiveStruct) {
   args <- list(RecursiveStruct = RecursiveStruct)
   interface <- Structure(
     RecursiveStruct = Structure(
-      RecursiveList = List(
-        Structure(
-          NoRecurse = Scalar(type = "string"),
-          RecursiveStruct = Structure(
-            NoRecurse = Scalar(type = "string")
-          )
-        )
-      )
+      RecursiveList = List(Structure(
+        NoRecurse = Scalar(type = "string"),
+        RecursiveStruct = Structure(NoRecurse = Scalar(type = "string"))
+      ))
     )
   )
   return(populate(args, interface))
@@ -228,26 +176,23 @@ test_that("build nested structure", {
     RecursiveStruct = list(
       RecursiveList = list(
         list(NoRecurse = "foo"),
-        list(RecursiveStruct = list(
-          NoRecurse = "bar"
-        ))
+        list(RecursiveStruct = list(NoRecurse = "bar"))
       )
     )
   )
   req <- new_request(svc, op, input, NULL)
   req <- build(req)
-  expect_equal(req$body, '{"RecursiveStruct":{"RecursiveList":[{"NoRecurse":"foo"},{"RecursiveStruct":{"NoRecurse":"bar"}}]}}')
+  expect_equal(
+    req$body,
+    '{"RecursiveStruct":{"RecursiveList":[{"NoRecurse":"foo"},{"RecursiveStruct":{"NoRecurse":"bar"}}]}}'
+  )
 })
 
 op_input10 <- function(RecursiveStruct) {
   args <- list(RecursiveStruct = RecursiveStruct)
   interface <- Structure(
     RecursiveStruct = Structure(
-      RecursiveMap = Map(
-        Structure(
-          NoRecurse = Scalar(type = "string")
-        )
-      )
+      RecursiveMap = Map(Structure(NoRecurse = Scalar(type = "string")))
     )
   )
   return(populate(args, interface))
@@ -256,30 +201,26 @@ op_input10 <- function(RecursiveStruct) {
 test_that("build nested structure", {
   input <- op_input10(
     RecursiveStruct = list(
-      RecursiveMap = list(
-        bar = list(NoRecurse = "bar"),
-        foo = list(NoRecurse = "foo")
-      )
+      RecursiveMap = list(bar = list(NoRecurse = "bar"), foo = list(NoRecurse = "foo"))
     )
   )
   req <- new_request(svc, op, input, NULL)
   req <- build(req)
-  expect_equal(req$body, '{"RecursiveStruct":{"RecursiveMap":{"bar":{"NoRecurse":"bar"},"foo":{"NoRecurse":"foo"}}}}')
+  expect_equal(
+    req$body,
+    '{"RecursiveStruct":{"RecursiveMap":{"bar":{"NoRecurse":"bar"},"foo":{"NoRecurse":"foo"}}}}'
+  )
 })
 
 op_input11 <- function(Map) {
   args <- list(Map = Map)
-  interface <- Structure(
-    Map = Map(Scalar(type = "string"))
-  )
+  interface <- Structure(Map = Map(Scalar(type = "string")))
   return(populate(args, interface))
 }
 
 test_that("build empty map", {
   skip("skip")
-  input <- op_input11(
-    Map = list()
-  )
+  input <- op_input11(Map = list())
   req <- new_request(svc, op, input, NULL)
   req <- build(req)
   expect_equal(req$body, '{"Map":{}}')
@@ -294,9 +235,7 @@ op_input12 <- function(Token = NULL) {
 }
 
 test_that("build idempotency token", {
-  input <- op_input12(
-    Token = "abc123"
-  )
+  input <- op_input12(Token = "abc123")
   req <- new_request(svc, op, input, NULL)
   req <- build(req)
   expect_equal(req$body, '{"Token":"abc123"}')
@@ -312,21 +251,20 @@ test_that("build idempotency token", {
 op_input13 <- function(FooEnum, ListEnums) {
   args <- list(FooEnum = FooEnum, ListEnums = ListEnums)
   interface <- Structure(
-    FooEnum = Scalar(type = "string", .tags = list(enum = "InputService8TestShapeEnumType")),
-    ListEnums = List(Scalar(type = "string", .tags = list(enum = "InputService8TestShapeEnumType")))
+    FooEnum = Scalar(
+      type = "string",
+      .tags = list(enum = "InputService8TestShapeEnumType")
+    ),
+    ListEnums = List(Scalar(
+      type = "string",
+      .tags = list(enum = "InputService8TestShapeEnumType")
+    ))
   )
   return(populate(args, interface))
 }
 
 test_that("build enums", {
-  input <- op_input13(
-    FooEnum = "foo",
-    ListEnums = list(
-      "foo",
-      "",
-      "bar"
-    )
-  )
+  input <- op_input13(FooEnum = "foo", ListEnums = list("foo", "", "bar"))
   req <- new_request(svc, op, input, NULL)
   req <- build(req)
   expect_equal(req$body, '{"FooEnum":"foo","ListEnums":["foo","","bar"]}')
@@ -356,68 +294,42 @@ test_that("build nested structure with incomplete input shape", {
   input <- op_input14(
     TableName = "myname",
     Item = list(
-      UserId = list(
-        S = "1"
-      ),
-      Day = list(
-        N = 1
-      ),
+      UserId = list(S = "1"),
+      Day = list(N = 1),
       HourMap = list(
-        M = list(
-          "1" = list(
-            N = "1"
-          ),
-          "2" = list(
-            N = "2"
-          ),
-          "3" = list(
-            N = "3"
-          )
-        )
+        M = list("1" = list(N = "1"), "2" = list(N = "2"), "3" = list(N = "3"))
       )
     )
   )
   req <- new_request(svc, op, input, NULL)
   req <- build(req)
   r <- req$http_request
-  expect_equal(r$body, '{"TableName":"myname","Item":{"Day":{"N":"1"},"HourMap":{"M":{"1":{"N":"1"},"2":{"N":"2"},"3":{"N":"3"}}},"UserId":{"S":"1"}}}')
+  expect_equal(
+    r$body,
+    '{"TableName":"myname","Item":{"Day":{"N":"1"},"HourMap":{"M":{"1":{"N":"1"},"2":{"N":"2"},"3":{"N":"3"}}},"UserId":{"S":"1"}}}'
+  )
 
   input <- op_input14(
     TableName = "myname",
     Item = list(
-      UserId = list(
-        S = "2"
-      ),
-      Day = list(
-        N = 1
-      ),
+      UserId = list(S = "2"),
+      Day = list(N = 1),
       Foo = list(
         L = list(
-          list(
-            M = list(
-              FooBar = list(
-                N = "1"
-              )
-            )
-          ),
-          list(
-            M = list(
-              FooBar = list(
-                N = "2"
-              )
-            )
-          )
+          list(M = list(FooBar = list(N = "1"))),
+          list(M = list(FooBar = list(N = "2")))
         )
       ),
-      Bar = list(
-        NS = list("1", "2", "3")
-      )
+      Bar = list(NS = list("1", "2", "3"))
     )
   )
   req <- new_request(svc, op, input, NULL)
   req <- build(req)
   r <- req$http_request
-  expect_equal(r$body, '{"TableName":"myname","Item":{"Bar":{"NS":["1","2","3"]},"Day":{"N":"1"},"Foo":{"L":[{"M":{"FooBar":{"N":"1"}}},{"M":{"FooBar":{"N":"2"}}}]},"UserId":{"S":"2"}}}')
+  expect_equal(
+    r$body,
+    '{"TableName":"myname","Item":{"Bar":{"NS":["1","2","3"]},"Day":{"N":"1"},"Foo":{"L":[{"M":{"FooBar":{"N":"1"}}},{"M":{"FooBar":{"N":"2"}}}]},"UserId":{"S":"2"}}}'
+  )
 })
 
 #-------------------------------------------------------------------------------
@@ -425,26 +337,17 @@ test_that("build nested structure with incomplete input shape", {
 # Build with no target prefix
 
 op <- Operation(name = "OperationName")
-svc <- Client(
-  client_info = ClientInfo(
-    json_version = "1.1",
-    target_prefix = NULL
-  )
-)
+svc <- Client(client_info = ClientInfo(json_version = "1.1", target_prefix = NULL))
 svc$handlers$build <- HandlerList(jsonrpc_build)
 
 op_input1 <- function(Name) {
   args <- list(Name = Name)
-  interface <- Structure(
-    Name = Scalar()
-  )
+  interface <- Structure(Name = Scalar())
   return(populate(args, interface))
 }
 
 test_that("build scalar members", {
-  input <- op_input1(
-    Name = "myname"
-  )
+  input <- op_input1(Name = "myname")
   req <- new_request(svc, op, input, NULL)
   req <- build(req)
   r <- req$http_request
@@ -475,7 +378,9 @@ test_that("unmarshal scalar members", {
   req <- new_request(svc, op, NULL, op_output1)
   req$http_response <- HttpResponse(
     status_code = 200,
-    body = charToRaw("{\"Str\": \"myname\", \"Num\": 123, \"FalseBool\": false, \"TrueBool\": true, \"Float\": 1.2, \"Double\": 1.3, \"Long\": 200, \"Char\": \"a\"}")
+    body = charToRaw(
+      "{\"Str\": \"myname\", \"Num\": 123, \"FalseBool\": false, \"TrueBool\": true, \"Float\": 1.2, \"Double\": 1.3, \"Long\": 200, \"Char\": \"a\"}"
+    )
   )
   req <- unmarshal(req)
   out <- req$data
@@ -500,7 +405,9 @@ test_that("unmarshal blobs", {
   req <- new_request(svc, op, NULL, op_output2)
   req$http_response <- HttpResponse(
     status_code = 200,
-    body = charToRaw("{\"BlobMember\": \"aGkh\", \"StructMember\": {\"foo\": \"dGhlcmUh\"}}")
+    body = charToRaw(
+      "{\"BlobMember\": \"aGkh\", \"StructMember\": {\"foo\": \"dGhlcmUh\"}}"
+    )
   )
   req <- unmarshal(req)
   out <- req$data
@@ -519,7 +426,9 @@ test_that("unmarshal timestamps", {
   req <- new_request(svc, op, NULL, op_output3)
   req$http_response <- HttpResponse(
     status_code = 200,
-    body = charToRaw("{\"TimeMember\": 1398796238, \"StructMember\": {\"foo\": 1398796238}}")
+    body = charToRaw(
+      "{\"TimeMember\": 1398796238, \"StructMember\": {\"foo\": 1398796238}}"
+    )
   )
   req <- unmarshal(req)
   out <- req$data
@@ -550,7 +459,9 @@ test_that("unmarshal list", {
   req <- new_request(svc, op, NULL, op_output4)
   req$http_response <- HttpResponse(
     status_code = 200,
-    body = charToRaw("{\"ListMember\": [\"a\", null], \"ListMemberMap\": [{}, null, null, {}], \"ListMemberStruct\": [{}, null, null, {}]}")
+    body = charToRaw(
+      "{\"ListMember\": [\"a\", null], \"ListMemberMap\": [{}, null, null, {}], \"ListMemberStruct\": [{}, null, null, {}]}"
+    )
   )
   req <- unmarshal(req)
   out <- req$data
@@ -566,9 +477,7 @@ test_that("unmarshal list", {
   expect_null(out$ListMemberStruct[[4]])
 })
 
-op_output5 <- Structure(
-  MapMember = Map(List(Scalar(type = "integer")))
-)
+op_output5 <- Structure(MapMember = Map(List(Scalar(type = "integer"))))
 
 test_that("unmarshal map", {
   req <- new_request(svc, op, NULL, op_output5)
@@ -584,9 +493,7 @@ test_that("unmarshal map", {
   expect_equal(out$MapMember[["b"]][2], 4)
 })
 
-op_output6 <- Structure(
-  StrType = Scalar(type = "string")
-)
+op_output6 <- Structure(StrType = Scalar(type = "string"))
 
 test_that("unmarshal ignores extra data", {
   req <- new_request(svc, op, NULL, op_output6)
@@ -601,8 +508,14 @@ test_that("unmarshal ignores extra data", {
 })
 
 op_output7 <- Structure(
-  FooEnum = Scalar(type = "string", .tags = list(enum = "OutputService7TestShapeJSONEnumType")),
-  ListEnums = List(Scalar(type = "string", .tags = list(enum = "OutputService7TestShapeJSONEnumType")))
+  FooEnum = Scalar(
+    type = "string",
+    .tags = list(enum = "OutputService7TestShapeJSONEnumType")
+  ),
+  ListEnums = List(Scalar(
+    type = "string",
+    .tags = list(enum = "OutputService7TestShapeJSONEnumType")
+  ))
 )
 
 test_that("unmarshal enums", {
@@ -639,7 +552,9 @@ test_that("unmarshal nested structure with incomplete output shape", {
   req <- new_request(svc, op, NULL, op_output8)
   req$http_response <- HttpResponse(
     status_code = 200,
-    body = charToRaw('{"Count":1,"Items":[{"UserId":{"S":"1"},"HourMap":{"M":{"1":{"N":"1"},"2":{"N":"2"},"3":{"N":"3"}}},"Day":{"N":"1"}}],"ScannedCount":1}')
+    body = charToRaw(
+      '{"Count":1,"Items":[{"UserId":{"S":"1"},"HourMap":{"M":{"1":{"N":"1"},"2":{"N":"2"},"3":{"N":"3"}}},"Day":{"N":"1"}}],"ScannedCount":1}'
+    )
   )
   req <- unmarshal(req)
   out <- req$data
@@ -653,7 +568,9 @@ test_that("unmarshal nested structure with incomplete output shape", {
   req <- new_request(svc, op, NULL, op_output8)
   req$http_response <- HttpResponse(
     status_code = 200,
-    body = charToRaw('{"Count":1,"Items":[{"UserId":{"S":"4"},"Day":{"N":"1"},"Bar":{"NS":["3","2","1"]},"Foo":{"L":[{"M":{"FooBar":{"N":"1"}}},{"M":{"FooBar":{"N":"2"}}}]}}],"ScannedCount":1}')
+    body = charToRaw(
+      '{"Count":1,"Items":[{"UserId":{"S":"4"},"Day":{"N":"1"},"Bar":{"NS":["3","2","1"]},"Foo":{"L":[{"M":{"FooBar":{"N":"1"}}},{"M":{"FooBar":{"N":"2"}}}]}}],"ScannedCount":1}'
+    )
   )
   req <- unmarshal(req)
   out <- req$data
@@ -672,7 +589,9 @@ test_that("unmarshal UTF-8 text", {
   req <- new_request(svc, op, NULL, op_output9)
   req$http_response <- HttpResponse(
     status_code = 200,
-    body = charToRaw('{\"SourceLanguageCode\":\"en\",\"TargetLanguageCode\":\"es\",\"TranslatedText\":\"Me voy a casa mañana.\"}')
+    body = charToRaw(
+      '{\"SourceLanguageCode\":\"en\",\"TargetLanguageCode\":\"es\",\"TranslatedText\":\"Me voy a casa mañana.\"}'
+    )
   )
   req <- unmarshal(req)
   out <- req$data
